@@ -29,8 +29,6 @@
 #include "pimo.h"
 #include "nepomukmainmodel.h"
 #include "class.h"
-#include "datamanagement.h"
-#include "createresourcejob.h"
 #include "resourcewatcher.h"
 #include "dbustypes.h"
 
@@ -89,6 +87,12 @@ Nepomuk2::ResourceData::ResourceData( const QUrl& uri, const QUrl& kickOffUri, c
         }
         else {
             m_nieUrl = kickOffUri;
+            if( m_nieUrl.isLocalFile() ) {
+                // Point to the actual file in the case of a system link
+                QFileInfo fileInfo(m_nieUrl.toLocalFile());
+                if( fileInfo.isSymLink() )
+                    m_nieUrl = KUrl::fromLocalFile( fileInfo.canonicalFilePath() );
+            }
             m_cache.insert( NIE::url(), m_nieUrl );
 
             QMutexLocker locker(&m_rm->mutex);
@@ -265,7 +269,7 @@ bool Nepomuk2::ResourceData::store()
         }
         types << m_type;
 
-        QDBusMessage msg = QDBusMessage::createMethodCall( QLatin1String("org.kde.nepomuk.DataManagement"),
+        QDBusMessage msg = QDBusMessage::createMethodCall( QLatin1String("org.kde.NepomukStorage"),
                                                            QLatin1String("/datamanagement"),
                                                            QLatin1String("org.kde.nepomuk.DataManagement"),
                                                            QLatin1String("createResource") );
@@ -317,7 +321,7 @@ bool Nepomuk2::ResourceData::store()
 // Caller must hold m_dataMutex
 void Nepomuk2::ResourceData::addToWatcher()
 {
-    if( m_watchEnabled && !m_addedToWatcher ) {
+    if( m_watchEnabled && !m_addedToWatcher && !m_uri.isEmpty() ) {
         //Obey the locking rules: the rm mutex gets locked before the dataMutex.
         m_dataMutex.unlock();
         //It is safe to use m_uri with dataMutex unlocked because it is only modified to set it, 
@@ -407,7 +411,7 @@ void Nepomuk2::ResourceData::setProperty( const QUrl& uri, const Nepomuk2::Varia
 
         QMutexLocker lock(&m_dataMutex);
         // update the store
-        QDBusMessage msg = QDBusMessage::createMethodCall( QLatin1String("org.kde.nepomuk.DataManagement"),
+        QDBusMessage msg = QDBusMessage::createMethodCall( QLatin1String("org.kde.NepomukStorage"),
                                                            QLatin1String("/datamanagement"),
                                                            QLatin1String("org.kde.nepomuk.DataManagement"),
                                                            QLatin1String("setProperty") );
@@ -463,7 +467,7 @@ void Nepomuk2::ResourceData::addProperty( const QUrl& uri, const Nepomuk2::Varia
         }
 
         QMutexLocker lock(&m_dataMutex);
-        QDBusMessage msg = QDBusMessage::createMethodCall( QLatin1String("org.kde.nepomuk.DataManagement"),
+        QDBusMessage msg = QDBusMessage::createMethodCall( QLatin1String("org.kde.NepomukStorage"),
                                                            QLatin1String("/datamanagement"),
                                                            QLatin1String("org.kde.nepomuk.DataManagement"),
                                                            QLatin1String("addProperty") );
@@ -498,7 +502,7 @@ void Nepomuk2::ResourceData::removeProperty( const QUrl& uri )
     QMutexLocker lock(&m_dataMutex);
 
     if( !m_uri.isEmpty() ) {
-        QDBusMessage msg = QDBusMessage::createMethodCall( QLatin1String("org.kde.nepomuk.DataManagement"),
+        QDBusMessage msg = QDBusMessage::createMethodCall( QLatin1String("org.kde.NepomukStorage"),
                                                            QLatin1String("/datamanagement"),
                                                            QLatin1String("org.kde.nepomuk.DataManagement"),
                                                            QLatin1String("removeProperties") );
@@ -531,7 +535,7 @@ void Nepomuk2::ResourceData::remove( bool recursive )
     QMutexLocker lock(&m_dataMutex);
 
     if( !m_uri.isEmpty() ) {
-        QDBusMessage msg = QDBusMessage::createMethodCall( QLatin1String("org.kde.nepomuk.DataManagement"),
+        QDBusMessage msg = QDBusMessage::createMethodCall( QLatin1String("org.kde.NepomukStorage"),
                                                            QLatin1String("/datamanagement"),
                                                            QLatin1String("org.kde.nepomuk.DataManagement"),
                                                            QLatin1String("removeResources") );
@@ -745,6 +749,20 @@ void Nepomuk2::ResourceData::updateKickOffLists(const QUrl& uri, const Nepomuk2:
     }
 }
 
+namespace {
+    // Returns true if the variant list was modified
+    bool removeInvalidValues(QList<Nepomuk2::Variant>& vList) {
+        bool modified = false;
+        foreach(const Nepomuk2::Variant& var, vList) {
+            if( var.isResource() && !var.toResource().isValid() ) {
+                vList.removeAll(var);
+                modified = true;
+            }
+        }
+
+        return modified;
+    }
+}
 // Since propertyRemoved and propertyAdded are called from the ResourceManager with the RM mutex already locked, 
 // it is ok for them to call updateKickOffLists while the dataMutex is locked.
 void Nepomuk2::ResourceData::propertyRemoved( const Types::Property &prop, const QVariant &value_ )
@@ -752,6 +770,12 @@ void Nepomuk2::ResourceData::propertyRemoved( const Types::Property &prop, const
     QMutexLocker lock(&m_dataMutex);
     const Variant value(value_);
     QList<Variant> vl = m_cache.value(prop.uri()).toVariantList();
+
+    // Remove all invalid values
+    if( removeInvalidValues(vl) ) {
+        m_cache[prop.uri()] = vl;
+    }
+
     if( vl.contains(value) ) {
         //
         // Remove that element and and also remove all empty elements
@@ -792,12 +816,11 @@ void Nepomuk2::ResourceData::setWatchEnabled(bool status)
 {
     QMutexLocker lock(&m_dataMutex);
     if( m_watchEnabled != status ) {
+        m_watchEnabled = status;
         if( status )
             addToWatcher();
         else
             removeFromWatcher();
-
-        m_watchEnabled = status;
     }
 }
 
