@@ -32,6 +32,8 @@
 
 namespace Nepomuk2 {
 
+    class SimpleResource;
+
     class SimpleIndexingJob : public KJob
     {
         Q_OBJECT
@@ -44,6 +46,16 @@ namespace Nepomuk2 {
         QUrl uri();
         QString mimeType();
 
+        /**
+         * Fills a new SimpleResource with the basic data of the fileUrl such
+         * as type, mimetype, and other stat info.
+         *
+         * \param mimeType Indicates the mimetype of the fileUrl. If a non emtpy value has been
+         *                 provided, then it will be used. Otherwise \p mimeType will be updated
+         *                 to reflect the new value
+         */
+        static SimpleResource createSimpleResource( const KUrl& fileUrl, QString* mimeType );
+
     private slots:
         void slotJobFinished(KJob* job);
 
@@ -52,7 +64,7 @@ namespace Nepomuk2 {
         QUrl m_resUri;
         QString m_mimeType;
 
-        QSet<QUrl> typesForMimeType(const QString& mimeType);
+        static QSet<QUrl> typesForMimeType(const QString& mimeType);
     };
 }
 
