@@ -28,5 +28,8 @@ namespace Nepomuk2 {
     /// remove all indexed data for \p url the datamanagement way
     KJob* clearIndexedData( const QUrl& url );
     KJob* clearIndexedData( const QList<QUrl>& urls );
+    /// update kext::indexingLevel for \p url
+    void updateIndexingLevel( const QUrl& uri, int level );
+
 }
 #endif
