@@ -115,6 +115,18 @@ QSet<QUrl> Nepomuk2::ClassAndPropertyTree::allParents(const QUrl &uri) const
         return QSet<QUrl>();
 }
 
+QSet<QUrl> Nepomuk2::ClassAndPropertyTree::allParents(const QList< QUrl >& types) const
+{
+    QSet<QUrl> all;
+    foreach(const QUrl& uri, types) {
+        all.unite( allParents(uri) );
+        all << uri;
+    }
+
+    return all;
+}
+
+
 bool Nepomuk2::ClassAndPropertyTree::isChildOf(const QUrl &type, const QUrl &superClass) const
 {
     if( type == superClass )
@@ -201,6 +213,7 @@ QSet<Soprano::Node> Nepomuk2::ClassAndPropertyTree::variantListToNodeSet(const Q
     clearError();
 
     QSet<Soprano::Node> nodes;
+    nodes.reserve( vl.size() );
 
     QUrl range;
     QVariant::Type literalType;
@@ -575,31 +588,6 @@ namespace {
     }
 }
 
-QList<Soprano::Statement> Nepomuk2::ClassAndPropertyTree::simpleResourceToStatementList(const Nepomuk2::SimpleResource &res) const
-{
-    const Soprano::Node subject = convertIfBlankNode(res.uri());
-    QList<Soprano::Statement> list;
-    PropertyHash properties = res.properties();
-    QHashIterator<QUrl, QVariant> it( properties );
-    while( it.hasNext() ) {
-        it.next();
-        const Soprano::Node object = variantToNode(it.value(), it.key());
-        list << Soprano::Statement(subject,
-                                   it.key(),
-                                   convertIfBlankNode(object));
-    }
-    return list;
-}
-
-QList<Soprano::Statement> Nepomuk2::ClassAndPropertyTree::simpleResourceGraphToStatementList(const Nepomuk2::SimpleResourceGraph &graph) const
-{
-    QList<Soprano::Statement> list;
-    foreach(const SimpleResource& res, graph.toList()) {
-        list += simpleResourceToStatementList(res);
-    }
-    return list;
-}
-
 Nepomuk2::ClassAndPropertyTree * Nepomuk2::ClassAndPropertyTree::self()
 {
     return s_self;
