@@ -54,6 +54,7 @@ public:
     bool isKnownClass(const QUrl& uri) const;
 
     QSet<QUrl> allParents(const QUrl& uri) const;
+    QSet<QUrl> allParents(const QList<QUrl>& types) const;
     bool isChildOf(const QUrl& type, const QUrl& superClass) const;
 
     /// Returns true if the uri is a Class or a Property
@@ -78,9 +79,6 @@ public:
     Soprano::Node variantToNode(const QVariant& value, const QUrl& property) const;
     QSet<Soprano::Node> variantListToNodeSet(const QVariantList& vl, const QUrl& property) const;
 
-    QList<Soprano::Statement> simpleResourceToStatementList(const Nepomuk2::SimpleResource& res) const;
-    QList<Soprano::Statement> simpleResourceGraphToStatementList(const Nepomuk2::SimpleResourceGraph& graph) const;
-
     static ClassAndPropertyTree* self();
 
 public Q_SLOTS:
